ImagePickerManager class

Constructors

ImagePickerManager({required AppImagePickerService pickerService, required IImageCropperService cropperService, required IImageCompressorService compressorService})

Properties

compressorService → IImageCompressorService
final
cropperService → IImageCropperService
final
hashCode → int
The hash code for this object.
no setterinherited
pickerService → AppImagePickerService
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickImage({required BuildContext context, required MountedCheck mounted, required ImageSource source, bool crop = false, bool compress = false, int quality = 35, double? maxHeight, double? maxWidth}) → Future<XFile?>
Picks an image from the given source, optionally crops and compresses it. Uses mounted callback to avoid context misuse after async gaps.
pickMultiImages({required BuildContext context, required MountedCheck mounted, bool crop = false, bool compress = false, int quality = 35}) → Future<List<XFile>>
Picks multiple images from the gallery, optionally crops and compresses each.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited