image_picker_adapter library

Enums

CameraDevice
Which camera to use when picking images/videos while source is ImageSource.camera.
ImageSource
Specifies the source where the picked image should come from.
RetrieveType
The type of the retrieved data in a LostDataResponse.

Constants

kTypeImage → const String
Denotes that an image is being picked.
kTypeVideo → const String
Denotes that a video is being picked.

Properties

imagePickerAdapterBlocProviders List<SingleChildWidget>
getter/setter pair
sl → GetIt
final

Typedefs

ImageCallback = dynamic Function(XFile? xFile)
MountedCheck = bool Function()
VoidImageCallback = void Function(XFile? file)
WidgetImageBuilder = Widget Function(XFile? file)
WidgetMultiImageBuilder = Widget Function(BuildContext context, List<XFile> currentFiles, {required bool isLoading})