AppImagePicker class

Inheritance

Constructors

AppImagePicker({Key? key, String? imageSource, int imageQuality = 35, double? maxHeight, double? maxWidth, bool crop = false, bool compress = false, WidgetImageBuilder? builder, ValueChanged<XFile?>? onChanged, bool cameraEnabled = true, bool galleryEnabled = true, bool autoResetOnPop = true, IImageSourceSelectorService sourceSelector = const ImageSourceSelectorService(), Widget? errorWidget, Widget? loadingWidget})
const

Properties

autoResetOnPop bool
Reset picker state when popped
final
builder WidgetImageBuilder?
Custom builder for picked file view
final
cameraEnabled bool
Source selection configuration
final
compress bool
final
crop bool
final
errorWidget Widget?
Custom UI widgets
final
galleryEnabled bool
final
hashCode int
The hash code for this object.
no setterinherited
imageQuality int
Picker configuration
final
imageSource String?
Fallback image path or URL
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingWidget Widget?
final
maxHeight double?
final
maxWidth double?
final
onChanged ValueChanged<XFile?>?
Callback when image is picked
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceSelector IImageSourceSelectorService
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited